/*
 * netconfig.h
 * Copyright (c) 1995 Be, Inc.	All Rights Reserved 
 *
 * Stuff for reading info out of the /boot/system/netconfig file
 */
#ifndef _NETCONFIG_H
#define _NETCONFIG_H

#if __cplusplus
extern "C" {
#endif /* __cplusplus */

#include <stdio.h>

#define NC_MAXCLASSLEN	256
#define NC_MAXNAMELEN	256
#define NC_MAXVALLEN	256

typedef struct _netconfig {
	FILE *ncfile;
	char ncbuf[1020];
} NETCONFIG;
	
typedef struct nc_entry {
	const char *key;
	const char *value;
} nc_entry_t;

typedef char nc_data_t[NC_MAXVALLEN];

typedef struct nc_private {
	nc_data_t key;
	nc_data_t value;
} nc_private_t;

typedef struct nc_section {
	const char *heading;
	unsigned nentries;
	nc_entry_t *entries;
} nc_section_t;


typedef struct ncwriter {
	int dirty;
	unsigned nsections;
	nc_section_t *sections;
} NCWRITER;

char *netconfig_find(const char *heading, const char *name, char *value);

int netconfig_set(const char *heading, const char *name, const char *value);

NETCONFIG *netconfig_open(const char *heading);

NCWRITER *ncwriter_open(void);
int ncwriter_set(NCWRITER *ncw, 
			 const char *heading, const char *name, const char *value);
#define ncwriter_isdirty(ncw) (ncw)->dirty
int ncwriter_save(NCWRITER *ncw);
char *ncwriter_find(NCWRITER *ncw, 
					const char *heading, const char *name, char *value);
void ncwriter_close(NCWRITER *ncw);

int netconfig_getnext(
					  NETCONFIG *netconfig,
					  char **name,
					  char **value
					  );

void netconfig_close(NETCONFIG *netconfig);

#if __cplusplus
}
#endif /* __cplusplus */

#endif /* _NETCONFIG_H */
